statusCodes: View a description the nloptr status codes

View source: R/utils.R

statusCodesR Documentation

View a description the nloptr status codes

Description

Prints a description of the status codes from the nloptr optimization routine.

Usage

statusCodes()

Value

No return value; prints a summary of the nloptr status codes to the console.

Examples

statusCodes()

logitr documentation built on July 6, 2026, 5:11 p.m.