This data frame contains the run times for a benchmark comparing the
relative computation time to estimate a preference space mixed logit model
using the following R packages: logitr, mixl, mlogit, gmnl, and apollo.
Packages that support parallel estimation (logitr, mixl, and apollo) are
benchmarked at multiple core counts, indicated in parentheses in the
package name (e.g. "logitr (1 cores)"). The benchmark is generated by the
script data-raw/runtimes.R in the package repository. The shipped results
were produced on a 10-core Apple M-series Mac, so the absolute times (and
the core counts benchmarked) are specific to that machine.
Usage
data(runtimes)Format
| Variable | Description |
package | Package name (with the number of cores in parentheses for packages benchmarked in parallel). |
time_sec | The estimation time in seconds. |
numDraws | The number of random draws used during estimation. |
version | The installed version of the package used for the benchmark. |
The data-raw/runtimes.R script in the logitr repository.
Examples
data(runtimes)
head(runtimes)
#> # A tibble: 6 × 4
#> package time_sec numDraws version
#> <fct> <dbl> <dbl> <chr>
#> 1 logitr (1 cores) 0.536 50 1.2.0
#> 2 logitr (5 cores) 0.216 50 1.2.0
#> 3 logitr (10 cores) 0.189 50 1.2.0
#> 4 mixl (1 cores) 6.03 50 1.3.5
#> 5 mixl (5 cores) 1.66 50 1.3.5
#> 6 mixl (10 cores) 3.00 50 1.3.5