| runtimes | R Documentation |
This data frame contains the run times for a benchmark comparing the
relative computation time to estimate a preference space mixed logit model
using the following R packages: logitr, mixl, mlogit, gmnl, and apollo.
Packages that support parallel estimation (logitr, mixl, and apollo) are
benchmarked at multiple core counts, indicated in parentheses in the
package name (e.g. "logitr (1 cores)"). The benchmark is generated by the
script data-raw/runtimes.R in the package repository. The shipped results
were produced on a 10-core Apple M-series Mac, so the absolute times (and
the core counts benchmarked) are specific to that machine.
data(runtimes)
| Variable | Description |
package | Package name (with the number of cores in parentheses for packages benchmarked in parallel). |
time_sec | The estimation time in seconds. |
numDraws | The number of random draws used during estimation. |
version | The installed version of the package used for the benchmark. |
The data-raw/runtimes.R script in the logitr repository.
data(runtimes)
head(runtimes)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.